@@ -1,7 +1,7 @@
 '''
 Author: BDFD
 Date: 2022-02-24 15:23:11
-LastEditTime: 2022-04-20 11:37:02
+LastEditTime: 2022-04-20 11:53:41
 LastEditors: BDFD
 Description: 
 FilePath: \5.2-PyPi-WES_Calculation\WES_Calculation\gumbel.py
@@ -16,15 +16,15 @@ import io
 import base64
 
 
-def gumbel(datao, unitt, unitx, i1, i2, i3):
-    # res = result
+def gumbel(result, unitt, unitx, i1, i2, i3):
+    res = result.split(",")
     # print('res is ', res,'and type is ', type(res))
     unitt = unitt
     # print('unitt is ', unitt,'and type is ', type(unitt))
     unitx = unitx
     # print('unitx is ', unitx,'and type is ', type(unitx))
-    # datao = list(map(float,res))
-    # datao = sorted(datao, reverse=True)
+    datao = list(map(float,res))
+    datao = sorted(datao, reverse=True)
     # print('datao is ', datao,'and type is ', type(datao))
     Tt=[2,5,10,20,25,50,100,200] # Typical return periods used in the output report  
     Tti=[1.005,2,3,4,5,10,20,30,40,50,60,70,80,90,100,200,500] # Return periods for plotting
@@ -215,4 +215,4 @@ def gumbel(datao, unitt, unitx, i1, i2, i3):
     img.seek(0)
     plot_url = base64.b64encode(img.getvalue()).decode()
     plt.close("all")
-    return (plot_url,test4,test5,test6,test7,test8,test10,data)
\ No newline at end of file
+    return (plot_url,data,test4,test5,test6,test7,test8,test10)
\ No newline at end of file
